@@ -23,7 +23,7 @@ def cal_mos_infer(testFile=None):
 
     """
     args = {'mode': 'predict_file', 'pretrained_model': 'SC_res_retrain_220316_185754125621__ep_007.tar',
-     'deg': 'test/input0.wav', 'data_dir': 'test', 'output_dir': None, 'csv_file': 'test-Copy1.csv',
+     'deg': '', 'data_dir': 'test', 'output_dir': None, 'csv_file': 'test-Copy1.csv',
      'csv_deg': 'filename', 'num_workers': 0, 'bs': 1, 'ms_channel': None, 'tr_bs_val': 1, 'tr_num_workers': 0,
      'task_type': 1}
     args['deg'] = testFile
