@@ -7,7 +7,7 @@ sys.path.append(os.path.dirname(path.dirname(__file__)))
 import wave
 import  time
 from ctypes import *
-from  formatConvert.wav_pcm import get_data_array
+from commFunction import get_data_array
 import numpy as np
 
 def resample(infile,target_amplerate,outfile=None):
